pub async fn path_is_referenced(
conn: &mut PgConnection,
path: &str,
) -> ModelResult<bool>Expand description
Whether a live page audio row still points at this storage path.
pub async fn path_is_referenced(
conn: &mut PgConnection,
path: &str,
) -> ModelResult<bool>Whether a live page audio row still points at this storage path.